#!/usr/bin/python
# -*- coding: utf-8 -*-
# 
#   FILE: Classification.py
#   DATE: March, 2014
#   Author: David W. McDonald
#
#   An object encapsulation of a simple binary classifier. This can read a
#   labeled CSV file and create a classifier based on the labeling provided
#   in the CSV file. This class is based on services provided by nltk
#
#   Copyright by Author. All rights reserved. Not for reuse without
#   express permissions.
#
import sys, csv, nltk
from datetime import datetime, timedelta
from hcde.utils.stop_words import remove_stops, STOPLIST


class Classification(object):
    def __init__(self):
        self.positive_category = "positive"
        self.negative_category = "negative"
        self.positive_labels = ['+', 'p', 'pos', 'positive', '+1', 1]
        self.negative_labels = ['-', 'n', 'neg', 'negative', '-1', -1]
        self.complete_token_list = []
        self.training_data = None
        self.classifier = None
    
    # Load a CSV file
    def load_csv_label_data(self,fname="", as_tokens=False, no_stops=True):
        label_data = []
        if( fname ):
            lines = 0
            pos_examples = 0
            neg_examples = 0
            unknown = 0
            f = open(fname,"r")
            reader = csv.DictReader(f,dialect="excel")
            rec = reader.next()
            while rec:
                lines += 1
                tweet_text = rec['tweet_text'].decode('utf-8')
                clean_tweet = tweet_text
                if( no_stops ):
                    clean_tweet = remove_stops(tweet_text)
                token_list = clean_tweet.split()
                label = rec['label']
                if( type(label) is str ):
                    label = label.lower()
                if( label in self.positive_labels ):
                    if( as_tokens ):
                        tup = (token_list,self.positive_category)
                    else:
                        tup = (clean_tweet,self.positive_category)
                    self.complete_token_list.extend(token_list)
                    pos_examples += 1
                elif( label in self.negative_labels ):
                    if( as_tokens ):
                        tup = (token_list,self.negative_category)
                    else:
                        tup = (clean_tweet,self.negative_category)
                    self.complete_token_list.extend(token_list)
                    neg_examples += 1
                else:
                    # this one is neutral or not labeled
                    tup = ()
                    unknown += 1
                if( tup ):
                    label_data.append(tup)
                try:
                    rec = reader.next()
                except:
                    rec = None
            f.close()
        return [label_data,lines,pos_examples,neg_examples,unknown]
    
    
    def parse_features(self, text=""):
        feature_dict = dict()
        
        # make sure we have a list of tokens
        tok_list = text
        if( type(text) is not list ):
            tok_list = text.split()
        
        # now check that each token is one that we want to use
        for tok in tok_list:
            feature_dict[tok] = (tok in self.complete_token_list)
        
        return feature_dict
    
    def train_new_classifier(self, label_data=None):
        self.training_data = nltk.classify.apply_features(self.parse_features,label_data)
        #self.classifier = nltk.classify.naivebayes.NaiveBayesClassifier.train(self.training_data)
        self.classifier = nltk.NaiveBayesClassifier.train(self.training_data)
        return 
    
    def top_n_features(self, n=10):
        self.classifier.show_most_informative_features(n=n)
        return
    
    def classify(self, text=None):
        if( text ):
            return self.classifier.classify(self.parse_features(text))
        else:
            return None


if __name__ == '__main__':
    print "The object Classification() can not be manipulated from the command line."

