#!/usr/bin/python
# -*- coding: utf-8 -*-
# 
#   FILE: TwitterLimits.py
#   DATE: December, 2015
#   Author: David W. McDonald
#
#   Making a call that simply results in the request limits
#
#   Copyright by Author. All rights reserved. Not for reuse without
#   express permissions.
#
import sys, time, json, random, logging
import requests
from requests.exceptions import HTTPError, URLRequired
from datetime import datetime
from hcde.twitter.Login import Login
from hcde.twitter.auth_settings import *
from hcde.twitter.TwitterBase import TwitterBase


def parse_params(argv):
    auth = None
    user = None
    resource = None
    res_type = None
    pc = 1
    while( pc < len(argv) ):
        param = argv[pc]
        if( param == "-res"):
            pc += 1
            resource = argv[pc]
        if( param == "-resource"):
            pc += 1
            resource = argv[pc]

        if( param == "-res_type"):
            pc += 1
            res_type = argv[pc]
        if( param == "-rt"):
            pc += 1
            res_type = argv[pc]

        if( param == "-auth"):
            pc += 1
            auth = argv[pc]
        if( param == "-user"):
            pc += 1
            user = argv[pc]
        if( param == "-log"):
            logging = True
        pc += 1
    return { 'auth':auth, 'user':user,
             'resource':resource, 'res_type':res_type }

def usage(argv):
    print "USAGE: python %s -auth <appname> -user <auth_user> [-res <resource>] [-res_type <resource_type]"%(argv[0])
    sys.exit(0)


def main(argv):
    if len(argv) < 5:
        usage(argv)
    p = parse_params(argv)
    #print p
    
    twit = TwitterBase()
    twit.set_user_agent(agent="random")
    
    lg = None
    if( not p['auth'] and not p['user'] ):
        print "Must have authenticating User and Application!"
        usage(argv)
        return

    if( p['auth'] ):
        app = p['auth']
        app_keys = TWITTER_APP_OAUTH_PAIR(app=p['auth'])
        app_token_fname = TWITTER_APP_TOKEN_FNAME(app=p['auth'])
        lg = Login( name="TestLoginObj",
                    app_name=p['auth'],
                    app_user=p['user'],
                    token_fname=app_token_fname)
        #lg.set_debug(True)
        ## Key and secret for specified application
        lg.set_consumer_key(consumer_key=app_keys['consumer_key'])
        lg.set_consumer_secret(consumer_secret=app_keys['consumer_secret'])
        lg.login()
        twit.set_auth_obj(obj=lg)

    if( p['resource'] ):
        if( p['res_type'] ):
            twit.set_rate_limit_resource(resource=p['resource'],resource_type=p['res_type'])
            twit.make_request()
        else:
            twit.set_rate_limit_resource(resource=p['resource'],resource_type="")
            twit.make_request()        
    else:
        print "\nLimits for search"
        twit.set_rate_limit_resource(resource="search",resource_type="tweets")
        twit.make_request()
        
        print "\nLimits for statuses"
        twit.set_rate_limit_resource(resource="statuses",resource_type="user_timeline")
        twit.make_request()
        twit.set_rate_limit_resource(resource="statuses",resource_type="lookup")
        twit.make_request()
        
        print "\nLimits for users"
        twit.set_rate_limit_resource(resource="users",resource_type="search")
        twit.make_request()
        twit.set_rate_limit_resource(resource="users",resource_type="lookup")
        twit.make_request()
        
        print "\nLimits for friends"
        twit.set_rate_limit_resource(resource="friends",resource_type="list")
        twit.make_request()
        
        print "\nLimits for followers"
        twit.set_rate_limit_resource(resource="followers",resource_type="list")
        twit.make_request()
    return

if __name__ == '__main__':
    main(sys.argv)   
